@@ -9,7 +9,7 @@ x = []
 for _ in range(randint(2, 10)):
     x.append(randint(1, 100))
 
-intro = f"You have to print the sum of {', '.join(str(_) for _ in x[:-1])} and {x[-1]}."
+intro = f"You have to print the sum of {', '.join(str(_) for _ in x[:-1])} and {x[-1]}. (values: x)"
 
 
 def validate_function(stdin: str, stdout: str, stderr: str, exc: tuple) -> bool:
